@@ -1,27 +1,12 @@
-/********************************************************************
- KSld - the KDE Screenlocker Daemon
- This file is part of the KDE project.
+/*
+    SPDX-FileCopyrightText: 1999 Martin R. Jones <mjones@kde.org>
+    SPDX-FileCopyrightText: 2003 Oswald Buddenhagen <ossi@kde.org>
+    SPDX-FileCopyrightText: 2008 Chani Armitage <chanika@gmail.com>
+    SPDX-FileCopyrightText: 2011 Martin Gräßlin <mgraesslin@kde.org>
 
- Copyright 1999 Martin R. Jones <mjones@kde.org>
- Copyright 2003 Oswald Buddenhagen <ossi@kde.org>
- Copyright 2008 Chani Armitage <chanika@gmail.com>
- Copyright (C) 2011 Martin Gräßlin <mgraesslin@kde.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
-#ifndef SCREENLOCKER_KSLDAPP_H
-#define SCREENLOCKER_KSLDAPP_H
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
+#pragma once
 
 #include <QElapsedTimer>
 #include <QProcessEnvironment>
@@ -35,21 +20,12 @@ class QTimer;
 class KSldTest;
 class PowerManagementInhibition;
 
-namespace KWayland
-{
-namespace Server {
-class Display;
-class ClientConnection;
-}
-}
-
 namespace ScreenLocker
 {
-
 enum class EstablishLock {
-    Immediate, ///Require password from the start. Use if invoked explicitly by the user
-    Delayed, ///Allow the user to log back in without a password for a configured grace time.
-    DefaultToSwitchUser ///UI should default to showing the "switch user dialog"
+    Immediate, /// Require password from the start. Use if invoked explicitly by the user
+    Delayed, /// Allow the user to log back in without a password for a configured grace time.
+    DefaultToSwitchUser, /// UI should default to showing the "switch user dialog"
 };
 
 class AbstractLocker;
@@ -59,21 +35,22 @@ class KSCREENLOCKER_EXPORT KSldApp : public QObject
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.ksld.App")
-    Q_ENUMS(LockState)
 
 public:
     enum LockState {
         Unlocked,
         AcquiringLock,
-        Locked
+        Locked,
     };
+    Q_ENUM(LockState)
 
-    static KSldApp* self();
+    static KSldApp *self();
 
-    explicit KSldApp(QObject * parent = nullptr);
+    explicit KSldApp(QObject *parent = nullptr);
     ~KSldApp() override;
 
-    LockState lockState() const {
+    LockState lockState() const
+    {
         return m_lockState;
     }
 
@@ -84,13 +61,11 @@ public:
 
     void configure();
 
+    void userActivity();
     bool isGraceTime() const;
 
-    void setWaylandDisplay(KWayland::Server::Display *display);
+    void setWaylandFd(int fd);
 
-    KWayland::Server::ClientConnection *greeterClientConnection() const {
-        return m_greeterClientConnection;
-    }
     void setGreeterEnvironment(const QProcessEnvironment &env);
 
     /**
@@ -100,7 +75,7 @@ public:
     void inhibit();
     void uninhibit();
 
-    void lock(EstablishLock establishLock);
+    void lock(EstablishLock establishLock, int attemptCount = 0);
     void initialize();
 
     bool event(QEvent *event) override;
@@ -109,28 +84,41 @@ public:
      * For testing
      * @internal
      **/
-    int idleId() const {
+    int idleId() const
+    {
         return m_idleId;
     }
     /**
      * For testing
      * @internal
      **/
-    void setIdleId(int idleId) {
+    void setIdleId(int idleId)
+    {
         m_idleId = idleId;
     }
     /**
      * For testing
      * @internal
      **/
-    void setGraceTime(int msec) {
+    void setGraceTime(int msec)
+    {
         m_lockGrace = msec;
     }
 
+    bool forceSoftwareRendering() const
+    {
+        return m_forceSoftwareRendering;
+    }
+
+    void setForceSoftwareRendering(bool force)
+    {
+        m_forceSoftwareRendering = force;
+    }
+
 Q_SIGNALS:
+    void aboutToLock();
     void locked();
     void unlocked();
-    void greeterClientConnectionChanged();
     void lockStateChanged();
 
 private Q_SLOTS:
@@ -148,14 +136,14 @@ private:
     void showLockWindow();
     void hideLockWindow();
     void doUnlock();
+    void lockProcessRequestedUnlock();
     bool isFdoPowerInhibited() const;
 
     LockState m_lockState;
     QProcess *m_lockProcess;
     AbstractLocker *m_lockWindow;
     WaylandServer *m_waylandServer;
-    KWayland::Server::Display *m_waylandDisplay;
-    KWayland::Server::ClientConnection *m_greeterClientConnection;
+
     /**
      * Timer to measure how long the screen is locked.
      * This information is required by DBus Interface.
@@ -179,6 +167,7 @@ private:
     LogindIntegration *m_logind;
     GlobalAccel *m_globalAccel = nullptr;
     bool m_hasXInput2 = false;
+    bool m_forceSoftwareRendering = false;
 
     bool m_isX11;
     bool m_isWayland;
@@ -186,9 +175,9 @@ private:
     QProcessEnvironment m_greeterEnv;
     PowerManagementInhibition *m_powerManagementInhibition;
 
+    int m_waylandFd = -1;
+
     // for auto tests
     friend KSldTest;
 };
 } // namespace
-
-#endif // SCREENLOCKER_KSLDAPP_H
